# SeisPro

A Python package containing some basic seismic processing tools

## Currently available tools
* [FXDECON](https://github.com/ar4/seispro/blob/master/notebooks/fxdecon.ipynb)
* [AGC](https://github.com/ar4/seispro/blob/master/notebooks/agc.ipynb)
* [TFCLIP](https://github.com/ar4/seispro/blob/master/notebooks/tfclip.ipynb)

## Installation
`pip install seispro`
